'use client'

import { useEffect, useState } from 'react'
import DashboardLayout from '@/components/layout/DashboardLayout'
import { FiUsers, FiPlus, FiUser, FiEdit, FiTrash } from 'react-icons/fi'
import Link from 'next/link'
import { staffService } from '@/services/api'
import { useUser } from '@/contexts/UserContext'

interface Staff {
  id: number
  name: string
  email: string
  role: string
  created_at: string
  admin?: number
  email_verified_at?: string | null
}

export default function StaffPage() {
  const [staffList, setStaffList] = useState<Staff[]>([])
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState<string | null>(null)
  const { user } = useUser()

  const fetchStaff = async () => {
    try {
      setLoading(true)
      if (!user?.token) return
      const response = await staffService.list(user.token)
      setStaffList(response.data.users || [])
    } catch (err: any) {
      setError(err.response?.data?.message || 'Personel listesi yüklenemedi')
      setStaffList([])
    } finally {
      setLoading(false)
    }
  }

  useEffect(() => {
    fetchStaff()
  }, [user?.token])

  const handleDelete = async (id: number) => {
    if (!user?.token) return
    
    try {
      await staffService.destroy(id.toString(), user.token)
      await fetchStaff()
    } catch (err: any) {
      setError(err.response?.data?.message || 'Silme işlemi başarısız')
    }
  }

  return (
    <DashboardLayout>
      <div className="space-y-6">
        <div className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm rounded-3xl shadow-lg">
          <div className="p-6 border-b border-slate-200/50 dark:border-slate-700/50">
            <div className="flex items-center justify-between">
              <h2 className="text-xl font-bold text-slate-800 dark:text-white flex items-center gap-2">
                <FiUsers className="w-5 h-5" />
                Personel Listesi
              </h2>
              <Link
                href="/dashboard/staff/add"
                className="inline-flex items-center gap-2 px-4 py-2 text-sm font-medium 
                         text-white bg-gradient-to-r from-fuchsia-500 to-purple-600 
                         rounded-xl hover:opacity-90 transition-all"
              >
                <FiPlus className="w-4 h-4" />
                Yeni Personel
              </Link>
            </div>
          </div>
          
          <div className="p-6">
            <div className="overflow-x-auto rounded-xl border border-slate-200/50 dark:border-slate-700/50">
              <table className="w-full">
                <thead className="bg-slate-50/50 dark:bg-slate-700/50">
                  <tr>
                    <th className="px-6 py-4 text-left text-sm font-semibold text-slate-600 dark:text-slate-300">Personel</th>
                    <th className="px-6 py-4 text-left text-sm font-semibold text-slate-600 dark:text-slate-300">E-posta</th>
                    <th className="px-6 py-4 text-left text-sm font-semibold text-slate-600 dark:text-slate-300">Rol</th>
                    <th className="px-6 py-4 text-left text-sm font-semibold text-slate-600 dark:text-slate-300">Kayıt Tarihi</th>
                    <th className="px-6 py-4 text-left text-sm font-semibold text-slate-600 dark:text-slate-300">İşlemler</th>
                  </tr>
                </thead>
                <tbody className="divide-y divide-slate-200/50 dark:divide-slate-700/50">
                  {staffList?.map((staff) => (
                    <tr 
                      key={staff.id}
                      className="hover:bg-slate-50/50 dark:hover:bg-slate-700/20 transition-colors"
                    >
                      <td className="px-6 py-4">
                        <div className="flex items-center gap-3">
                          <div className="w-9 h-9 rounded-lg bg-gradient-to-r from-fuchsia-500 to-purple-600 flex items-center justify-center shadow">
                            <FiUser className="w-4 h-4 text-white" />
                          </div>
                          <span className="font-medium text-slate-800 dark:text-slate-100">
                            {staff.name}
                          </span>
                        </div>
                      </td>
                      <td className="px-6 py-4 text-slate-600 dark:text-slate-300">
                        {staff.email}
                      </td>
                      <td className="px-6 py-4">
                        <span className="inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-white dark:bg-slate-600 border border-slate-200 dark:border-slate-500 text-slate-700 dark:text-slate-200">
                          {staff.role === 'admin' ? 'Admin' : 'Personel'}
                        </span>
                      </td>
                      <td className="px-6 py-4 text-slate-500 dark:text-slate-400">
                        {new Date(staff.created_at).toLocaleDateString('tr-TR')}
                      </td>
                      <td className="px-6 py-4">
                        <div className="flex items-center gap-2">
                          <button 
                            onClick={() => handleDelete(staff.id)}
                            className="text-slate-500 dark:text-slate-400 hover:text-red-500 dark:hover:text-red-400 transition-colors"
                          >
                            <FiTrash className="w-4 h-4" />
                          </button>
                        </div>
                      </td>
                    </tr>
                  ))}
                </tbody>
              </table>

              {!loading && staffList?.length === 0 && (
                <div className="text-center py-8 text-slate-500 dark:text-slate-400">
                  Kayıtlı personel bulunamadı
                </div>
              )}
            </div>
          </div>
        </div>
      </div>


    </DashboardLayout>
  )
} 